translate.convert.xliff2oo

Package translate :: Package convert :: Module xliff2oo |
[hide private]
[frames] | no frames]

# Module xliff2oo

source code

convert XLIFF localization files to an OpenOffice.org (SDF) localization file

Classes | [hide private]
| reoo
| oocheckfilter
| oofilteroptions

Functions | [hide private]
getmtime(filename) | source code
convertoo(inputfile, outputfile, templatefile, sourcelanguage=None, targetlanguage=None, timestamp=None, includefuzzy=False, multifilestyle="single", filteraction=None) | source code
main(argv=None) | source code

Variables | [hide private]
| options = `oofilteroptions()`
| filter = `oocheckfilter(options, [checks.OpenOfficeChecker, che`...``

Imports: sys, os, oo, factory, pofilter, checks, autocorrect, time

Variables Details | [hide private]

  ### filter Value:
      oocheckfilter(options, [checks.OpenOfficeChecker, checks.StandardUnitC
      hecker], checks.openofficeconfig)